models

package
v0.0.0-...-c5ec0f1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 13, 2018 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

Announcements broadcasts winning validator to all nodes in POS blockchain

var Blockchain []Block
var BlockchainServer chan []Block
var CandidateBlocks = make(chan Block)

CandidateBlocks handles incoming blocks for validation in POS blockchain

var Cluster []string

Cluster is the array of servers that make up the blockchain system in the local network. Hardcoded for now

var InputMsgChan chan Message
var Mutex = &sync.Mutex{}
var TempCandidateBlocks []Block
var Validators = make(map[string]int)

Validators keeps track of open validators and balances in POS blockchain

Functions

This section is empty.

Types

type Block

type Block struct {
	Index     int64
	Timestamp string
	Data      []byte
	Hash      string
	PrevHash  string
	Validator string
}

type Message

type Message struct {
	Data      string
	Validator string
}

Jump to